@@ -463,245 +463,6 @@ def am_2_cmake_string(amstring):
 
     return s
 
-str1="""# $Id: Makefile.am 8330 2012-08-09 08:12:25Z sander $
-
-#
-## Find out which tests can be built
-#
-
-if ALBERTA
-  APROG = test-alberta-1-1 test-alberta-1-2 test-alberta-2-2 \
-          test-alberta-1-3 test-alberta-2-3 test-alberta-3-3 \
-          test-alberta-generic
-  ALBERTA_EXTRA_PROGS = test-alberta
-endif
-
-if ALUGRID
-  ALUPROG = test-alugrid
-endif
-
-if UG
-  UPROG = test-ug test-parallel-ug
-if ALUGRID
-  DGFALU_UGGRID = test-dgfalu-uggrid-combination
-else
-  DGFALU_UGGRID = 
-endif
-endif
-
-#
-## Defines for gridtype.hh
-#
-GRIDTYPE=YASPGRID
-GRIDDIM=2
-
-ALBERTA_DIM = $(WORLDDIM)
-
-#
-## Some parameters for the geogrid test
-#
-COORDFUNCTION = IdenticalCoordFunction\<double,$(GRIDDIM)\>
-# COORDFUNCTION = Helix
-# COORDFUNCTION = ThickHelix
-# COORDFUNCTION = DGFCoordFunction\<$(GRIDDIM),$(GRIDDIM)\>
-# COORDFUNCTION = DGFCoordFunction\<2,3\>
-CACHECOORDFUNCTION = 0
-
-#
-## define the lists of tests to build and run
-#
-
-# tests where program to build and program to run are equal
-NORMALTESTS = test-sgrid test-oned test-yaspgrid test-geogrid $(APROG) $(UPROG) $(ALUPROG) $(DGFALU_UGGRID)
-
-# list of tests to run
-TESTS = $(NORMALTESTS)
-
-# programs just to build when "make check" is used
-check_PROGRAMS = $(NORMALTESTS)
-
-EXTRA_PROGRAMS = $(ALBERTA_EXTRA_PROGS)
-
-#
-## common flags
-#
-
-# paranoia
-DUNE_EXTRA_CHECKS = -DDUNE_DEVEL_MODE
-# output coverage
-#COVERAGE = -fprofile-arcs -ftest-coverage
-AM_CXXFLAGS = $(COVERAGE)
-AM_CPPFLAGS = @AM_CPPFLAGS@ $(DUNE_EXTRA_CHECKS)
-
-# The directory where the example grid files used for testing are located
-AM_CPPFLAGS+=-DDUNE_GRID_EXAMPLE_GRIDS_PATH=\"$(top_srcdir)/doc/grids/\"
-
-#
-## define the programs
-#
-
-test_sgrid_SOURCES = test-sgrid.cc
-
-test_oned_SOURCES = test-oned.cc
-
-test_yaspgrid_SOURCES = test-yaspgrid.cc
-test_yaspgrid_CPPFLAGS = $(AM_CPPFLAGS)		\
-	$(DUNEMPICPPFLAGS)
-test_yaspgrid_LDFLAGS = $(AM_LDFLAGS)		\
-	$(DUNEMPILDFLAGS)
-test_yaspgrid_LDADD =				\
-	$(DUNEMPILIBS)				\
-	$(LDADD)
-
-# this implicitly checks the autoconf-test as well...
-test_alberta_SOURCES = test-alberta.cc
-test_alberta_CPPFLAGS = $(AM_CPPFLAGS) $(ALBERTA_CPPFLAGS) -DGRIDDIM=$(GRIDDIM) $(GRAPE_CPPFLAGS)
-test_alberta_LDFLAGS = $(AM_LDFLAGS) $(ALBERTA_LDFLAGS) $(GRAPE_LDFLAGS)
-test_alberta_LDADD =				\
-	$(GRAPE_LIBS)				\
-	$(ALBERTA_LIBS)				\
-	$(LDADD)
-
-test_alberta_1_1_SOURCES = test-alberta.cc
-test_alberta_1_1_CPPFLAGS = -DGRIDDIM=1 -DWORLDDIM=1 $(ALBERTA1D_CPPFLAGS) $(GRAPE_CPPFLAGS) $(AM_CPPFLAGS)
-test_alberta_1_1_LDFLAGS = $(ALBERTA1D_LDFLAGS) $(GRAPE_LDFLAGS) $(AM_LDFLAGS)
-test_alberta_1_1_LDADD = $(ALBERTA1D_LIBS) $(GRAPE_LIBS) $(LDADD)
-
-test_alberta_1_2_SOURCES = test-alberta.cc
-test_alberta_1_2_CPPFLAGS = -DGRIDDIM=1 -DWORLDDIM=2 $(ALBERTA2D_CPPFLAGS) $(GRAPE_CPPFLAGS) $(AM_CPPFLAGS)
-test_alberta_1_2_LDFLAGS = $(ALBERTA2D_LDFLAGS) $(GRAPE_LDFLAGS) $(AM_LDFLAGS)
-test_alberta_1_2_LDADD = $(ALBERTA2D_LIBS) $(GRAPE_LIBS) $(LDADD)
-
-test_alberta_2_2_SOURCES = test-alberta.cc
-test_alberta_2_2_CPPFLAGS = -DGRIDDIM=2 -DWORLDDIM=2 $(ALBERTA2D_CPPFLAGS) $(GRAPE_CPPFLAGS) $(AM_CPPFLAGS)
-test_alberta_2_2_LDFLAGS = $(ALBERTA2D_LDFLAGS) $(GRAPE_LDFLAGS) $(AM_LDFLAGS)
-test_alberta_2_2_LDADD = $(ALBERTA2D_LIBS) $(GRAPE_LIBS) $(LDADD)
-
-test_alberta_1_3_SOURCES = test-alberta.cc
-test_alberta_1_3_CPPFLAGS = -DGRIDDIM=1 -DWORLDDIM=3 $(ALBERTA3D_CPPFLAGS) $(GRAPE_CPPFLAGS) $(AM_CPPFLAGS)
-test_alberta_1_3_LDFLAGS = $(ALBERTA3D_LDFLAGS) $(GRAPE_LDFLAGS) $(AM_LDFLAGS)
-test_alberta_1_3_LDADD = $(ALBERTA3D_LIBS) $(GRAPE_LIBS) $(LDADD)
-
-test_alberta_2_3_SOURCES = test-alberta.cc
-test_alberta_2_3_CPPFLAGS = -DGRIDDIM=2 -DWORLDDIM=3 $(ALBERTA3D_CPPFLAGS) $(GRAPE_CPPFLAGS) $(AM_CPPFLAGS)
-test_alberta_2_3_LDFLAGS = $(ALBERTA3D_LDFLAGS) $(GRAPE_LDFLAGS) $(AM_LDFLAGS)
-test_alberta_2_3_LDADD = $(ALBERTA3D_LIBS) $(GRAPE_LIBS) $(LDADD)
-
-test_alberta_3_3_SOURCES = test-alberta.cc
-test_alberta_3_3_CPPFLAGS = -DGRIDDIM=3 -DWORLDDIM=3 $(ALBERTA3D_CPPFLAGS) $(GRAPE_CPPFLAGS) $(AM_CPPFLAGS)
-test_alberta_3_3_LDFLAGS = $(ALBERTA3D_LDFLAGS) $(GRAPE_LDFLAGS) $(AM_LDFLAGS)
-test_alberta_3_3_LDADD = $(ALBERTA3D_LIBS) $(GRAPE_LIBS) $(LDADD)
-
-test_alberta_generic_SOURCES = $(test_alberta_SOURCES)
-test_alberta_generic_CPPFLAGS = $(test_alberta_CPPFLAGS) -DDUNE_ALBERTA_USE_GENERICGEOMETRY=1
-test_alberta_generic_LDFLAGS = $(test_alberta_LDFLAGS)
-test_alberta_generic_LDADD = $(test_alberta_LDADD)
-
-# files for alugrid
-test_alugrid_SOURCES = test-alugrid.cc
-test_alugrid_CPPFLAGS = $(AM_CPPFLAGS)		\
-	$(ALL_PKG_CPPFLAGS)
-test_alugrid_LDFLAGS = $(AM_LDFLAGS)		\
-	$(ALL_PKG_LDFLAGS)			\
-	-static
-test_alugrid_LDADD =				\
-	$(ALL_PKG_LIBS)				\
-	$(LDADD)
-
-test_geogrid_SOURCES = test-geogrid.cc functions.hh
-test_geogrid_CPPFLAGS = $(AM_CPPFLAGS)			\
-	$(ALL_PKG_CPPFLAGS)				\
-	-DCOORDFUNCTION=$(COORDFUNCTION)		\
-	-DCACHECOORDFUNCTION=$(CACHECOORDFUNCTION)
-test_geogrid_LDFLAGS = $(AM_LDFLAGS)		\
-	$(ALL_PKG_LDFLAGS)
-test_geogrid_LDADD =				\
-	$(ALL_PKG_LIBS)				\
-	$(LDADD)
-
-# libdune contains both libugX2 and libugX3, always test both dimensions
-test_ug_SOURCES = test-ug.cc
-test_ug_CPPFLAGS = $(AM_CPPFLAGS)		\
-	$(DUNEMPICPPFLAGS)			\
-	$(UG_CPPFLAGS)
-test_ug_LDFLAGS = $(AM_LDFLAGS)			\
-	$(DUNEMPILDFLAGS)			\
-	$(UG_LDFLAGS)
-test_ug_LDADD =					\
-	$(UG_LIBS)				\
-	$(DUNEMPILIBS)				\
-	$(LDADD)
-
-# libdune contains both libugX2 and libugX3, always test both dimensions
-test_parallel_ug_SOURCES = test-parallel-ug.cc
-test_parallel_ug_CPPFLAGS = $(AM_CPPFLAGS)	\
-	$(DUNEMPICPPFLAGS)			\
-	$(UG_CPPFLAGS)
-test_parallel_ug_LDFLAGS = $(AM_LDFLAGS)	\
-	$(DUNEMPILDFLAGS)			\
-	$(UG_LDFLAGS)
-test_parallel_ug_LDADD =			\
-	$(UG_LIBS)				\
-	$(DUNEMPILIBS)				\
-	$(LDADD)
-
-# Test whether you can combine the different implementations in one file
-test_dgfalu_uggrid_combination_SOURCES = test-dgfalu-uggrid-combination.cc
-test_dgfalu_uggrid_combination_CPPFLAGS = $(AM_CPPFLAGS) $(UG_CPPFLAGS) $(ALUGRID_CPPFLAGS)
-test_dgfalu_uggrid_combination_LDFLAGS = $(AM_LDFLAGS) $(UG_LDFLAGS) $(ALUGRID_LDFLAGS)
-test_dgfalu_uggrid_combination_LDADD =		\
-	$(ALUGRID_LIBS)				\
-	$(UG_LIBS)				\
-	$(LDADD)
-
-## distribution tarball
-SOURCES = gridcheck.cc staticcheck.hh checkindexset.cc checkgeometryinfather.cc checkintersectionit.cc checkcommunicate.cc checkiterators.cc checktwists.cc check-albertareader.cc basicunitcube.hh checkadaptation.cc checkgeometry.cc checkpartition.cc checkentityseed.cc
-
-# gridcheck not used explicitly, we should still ship it :)
-EXTRA_DIST = $(SOURCES)
-
-CLEANFILES = *.gcda *.gcno semantic.cache simplex-testgrid*.dgf.* cube-testgrid*.dgf.* dgfparser.log
-
-include $(top_srcdir)/am/global-rules
-
-doxygendir = $(datadir)/doc/dune-localfunctions/doxygen
-doxygen_DATA = $(WHAT)
-
-# install the html pages
-docdir=$(datadir)/doc/dune-common/buildsystem
-if BUILD_DOCS
-  DOCFILES=buildsystem.pdf
-  EXTRA_DIST=$(DOCFILES)
-  EXTRAINSTALL=$(DOCFILES)
-endif
-
-all: $(WHAT) $(DOXYGENFILES)
-clean-local:
-        if test "x$(VPATH)" != "x" && test ! -e $(srcdir)/doxygen-tag; then \
-          if test -e $(top_srcdir)/doc/doxygen/Doxydep; then \
-            rm -rf $(SVNCLEANFILES); \
-          fi; \
-        fi
-# also build these sub directories
-SUBDIRS = doxygen buildsystem
-docdir=$(datadir)/doc/dune-common
-doc_DATA=data_bla data_blu
-doc_PROGRAMS= balla
-XFAIL_TESTS=ftest1 ftest2 ftest3
-COMPILE_XFAIL_TESTS=cftest1 cftest2
-"""
-
-#print am_2_cmake_string("""# which tests to run
-#TESTS = lagrangeshapefunctiontest		\
-#	monomshapefunctiontest			\
-#	virtualshapefunctiontest		\
-#	testgenericfem              \
-#	$(ALUPROG)
-#""")
-
-str2=''.join(['TESTS = lagrangeshapefunctiontest \\\n', '\tmonomshapefunctiontest\t\t\t\\\n', '\tvirtualshapefunctiontest\t\t\\\n', '\ttestgenericfem              \\\n', '\t$(ALUPROG)\n'])
-#print "s=%s" % output
-
 def init_cmake_module(module_name):
     return''.join(['# set up project\n',
                   'project("'+module_name+'" C CXX)\n\n#circumvent not building docs\nset(BUILD_DOCS 1)\n\n',
@@ -801,7 +562,7 @@ def am_2_cmake_dir(directory):
 'add_doxygen_target()']))
         output.close()
     # Add directives to create CMake packe configuration files with autotools
-    output=open("Makefile.am'", "a")
+    output=open("Makefile.am", "a")
     output.write('\n'.join(['', '# Generate package configuration files for finding',
                             '# installed modules with CMake',
                             'include $(top_srcdir)/am/cmake-pkg-config\n']))
