@@ -25,19 +25,19 @@ ParameterTree::ParameterTree()
 void ParameterTree::report(std::ostream& stream, const std::string& prefix) const
 {
   typedef std::map<std::string, std::string>::const_iterator ValueIt;
-  ValueIt vit = values.begin();
-  ValueIt vend = values.end();
+  ValueIt vit = values_.begin();
+  ValueIt vend = values_.end();
 
   for(; vit!=vend; ++vit)
     stream << vit->first << " = \"" << vit->second << "\"" << std::endl;
 
   typedef std::map<std::string, ParameterTree>::const_iterator SubIt;
-  SubIt sit = subs.begin();
-  SubIt send = subs.end();
+  SubIt sit = subs_.begin();
+  SubIt send = subs_.end();
   for(; sit!=send; ++sit)
   {
-    stream << "[ " << prefix + sit->first << " ]" << std::endl;
-    (sit->second).report(stream, prefix + sit->first + ".");
+    stream << "[ " << prefix + prefix_ + sit->first << " ]" << std::endl;
+    (sit->second).report(stream, prefix);
   }
 }
 
@@ -48,14 +48,14 @@ bool ParameterTree::hasKey(const std::string& key) const
   if (dot != std::string::npos)
   {
     std::string prefix = key.substr(0,dot);
-    if (subs.count(prefix) == 0)
+    if (subs_.count(prefix) == 0)
       return false;
 
     const ParameterTree& s = sub(prefix);
     return s.hasKey(key.substr(dot+1));
   }
   else
-    return (values.count(key) != 0);
+    return (values_.count(key) != 0);
 }
 
 bool ParameterTree::hasSub(const std::string& key) const
@@ -65,14 +65,14 @@ bool ParameterTree::hasSub(const std::string& key) const
   if (dot != std::string::npos)
   {
     std::string prefix = key.substr(0,dot);
-    if (subs.count(prefix) == 0)
+    if (subs_.count(prefix) == 0)
       return false;
 
     const ParameterTree& s = sub(prefix);
     return s.hasSub(key.substr(dot+1));
   }
   else
-    return (subs.count(key) != 0);
+    return (subs_.count(key) != 0);
 }
 
 ParameterTree& ParameterTree::sub(const std::string& key)
@@ -86,9 +86,10 @@ ParameterTree& ParameterTree::sub(const std::string& key)
   }
   else
   {
-    if (subs.count(key) == 0)
-      subKeys.push_back(key.substr(0,dot));
-    return subs[key];
+    if (subs_.count(key) == 0)
+      subKeys_.push_back(key.substr(0,dot));
+    subs_[key].prefix_ = prefix_ + key + ".";
+    return subs_[key];
   }
 }
 
@@ -103,9 +104,10 @@ const ParameterTree& ParameterTree::sub(const std::string& key) const
   }
   else
   {
-    if (subs.count(key) == 0)
-      DUNE_THROW(Dune::RangeError, "Key '" << key << "' not found in ParameterTree");
-    return subs.find(key)->second;
+    if (subs_.count(key) == 0)
+      DUNE_THROW(Dune::RangeError, "SubTree '" << key
+        << "' not found in ParameterTree (prefix " + prefix_ + ")");
+    return subs_.find(key)->second;
   }
 }
 
@@ -115,19 +117,19 @@ std::string& ParameterTree::operator[] (const std::string& key)
 
   if (dot != std::string::npos)
   {
-    if (not (hasSub(key.substr(0,dot))))
+    if (! hasSub(key.substr(0,dot)))
     {
-      subs[key.substr(0,dot)];
-      subKeys.push_back(key.substr(0,dot));
+      subs_[key.substr(0,dot)];
+      subKeys_.push_back(key.substr(0,dot));
     }
     ParameterTree& s = sub(key.substr(0,dot));
     return s[key.substr(dot+1)];
   }
   else
   {
-    if (not (hasKey(key)))
-      valueKeys.push_back(key);
-    return values[key];
+    if (! hasKey(key))
+      valueKeys_.push_back(key);
+    return values_[key];
   }
 }
 
@@ -137,16 +139,15 @@ const std::string& ParameterTree::operator[] (const std::string& key) const
 
   if (dot != std::string::npos)
   {
-    if (not (hasSub(key.substr(0,dot))))
-      DUNE_THROW(Dune::RangeError, "Key '" << key << "' not found in ParameterTree");
     const ParameterTree& s = sub(key.substr(0,dot));
     return s[key.substr(dot+1)];
   }
   else
   {
-    if (not (hasKey(key)))
-      DUNE_THROW(Dune::RangeError, "Key '" << key << "' not found in ParameterTree");
-    return values.find(key)->second;
+    if (! hasKey(key))
+      DUNE_THROW(Dune::RangeError, "Key '" << key
+        << "' not found in ParameterTree (prefix " + prefix_ + ")");
+    return values_.find(key)->second;
   }
 }
 
@@ -166,24 +167,6 @@ std::string ParameterTree::get(const std::string& key, const char* defaultValue)
     return defaultValue;
 }
 
-
-int ParameterTree::get(const std::string& key, int defaultValue) const
-{
-  std::stringstream stream;
-  stream << defaultValue;
-  std::string ret = get(key, stream.str());
-
-  return atoi(ret.c_str());
-}
-
-double ParameterTree::get(const std::string& key, double defaultValue) const
-{
-  if(hasKey(key))
-    return atof((*this)[key].c_str());
-  else
-    return defaultValue;
-}
-
 std::string ParameterTree::ltrim(const std::string& s)
 {
   std::size_t firstNonWS = s.find_first_not_of(" \t\n\r");
@@ -220,10 +203,10 @@ std::vector<std::string> ParameterTree::split(const std::string & s) {
 
 const ParameterTree::KeyVector& ParameterTree::getValueKeys() const
 {
-  return valueKeys;
+  return valueKeys_;
 }
 
 const ParameterTree::KeyVector& ParameterTree::getSubKeys() const
 {
-  return subKeys;
+  return subKeys_;
 }
