@@ -1,8 +1,6 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 
-// $Id$
-
 // make sure assert works even when not compiling for debugging
 #ifdef NDEBUG
 #undef NDEBUG
@@ -12,14 +10,6 @@
 #include "config.h"
 #endif
 
-#if defined(DISABLE_TR1_TUPLE) && defined(HAVE_TR1_TUPLE)
-#undef HAVE_TR1_TUPLE
-#endif
-
-#if defined(DISABLE_STD_TUPLE) && defined(HAVE_TUPLE)
-#undef HAVE_TUPLE
-#endif
-
 #include <cassert>
 #include <cstdlib>
 #include <iostream>
@@ -62,7 +52,7 @@ int iteratorTupleTest()
 
 
   Tuple tuple_(v.begin(), v.begin(), v.end());
-  dune_static_assert(tuple_size<Tuple>::value==3, "The tuple size should be 3!");;
+  static_assert(tuple_size<Tuple>::value==3, "The tuple size should be 3!");;
 
   int ret=0;
 
